Documentation
¶
Index ¶
- func AddressFromBookkeepers(bookkeepers []keypair.PublicKey) (common.Address, error)
- func AddressFromMultiPubKeys(pubkeys []keypair.PublicKey, m int) (common.Address, error)
- func AddressFromPubKey(pubkey keypair.PublicKey) common.Address
- func AddressFromVmCode(code []byte) common.Address
- func IsValidAttributeType(usage TransactionAttributeUsage) bool
- type Block
- func (b *Block) Deserialize(r io.Reader) error
- func (b *Block) FromTrimmedData(r io.Reader) error
- func (b *Block) Hash() common.Uint256
- func (b *Block) RebuildMerkleRoot()
- func (b *Block) Serialize(w io.Writer) error
- func (bd *Block) SerializeUnsigned(w io.Writer) error
- func (b *Block) ToArray() []byte
- func (b *Block) Trim(w io.Writer) error
- func (b *Block) Type() common.InventoryType
- type Header
- func (bd *Header) Deserialize(r io.Reader) error
- func (bd *Header) DeserializeUnsigned(r io.Reader) error
- func (bd *Header) GetMessage() []byte
- func (bd *Header) Hash() common.Uint256
- func (bd *Header) Serialize(w io.Writer) error
- func (bd *Header) SerializeUnsigned(w io.Writer) error
- func (bd *Header) ToArray() []byte
- type Payload
- type Sig
- type SmartCodeEvent
- type Transaction
- func (tx *Transaction) Deserialize(r io.Reader) error
- func (tx *Transaction) DeserializeUnsigned(r io.Reader) error
- func (tx *Transaction) GetMessage() []byte
- func (self *Transaction) GetSignatureAddresses() []common.Address
- func (tx *Transaction) Hash() common.Uint256
- func (tx *Transaction) Serialize(w io.Writer) error
- func (tx *Transaction) SerializeUnsigned(w io.Writer) error
- func (tx *Transaction) SetHash(hash common.Uint256)
- func (tx *Transaction) ToArray() []byte
- func (tx *Transaction) Type() common.InventoryType
- func (tx *Transaction) Verify() error
- type TransactionAttributeUsage
- type TransactionType
- type TxAttribute
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddressFromBookkeepers ¶
func AddressFromMultiPubKeys ¶
func AddressFromVmCode ¶
func IsValidAttributeType ¶
func IsValidAttributeType(usage TransactionAttributeUsage) bool
Types ¶
type Block ¶
type Block struct {
Header *Header
Transactions []*Transaction
}
func (*Block) RebuildMerkleRoot ¶
func (b *Block) RebuildMerkleRoot()
func (*Block) Type ¶
func (b *Block) Type() common.InventoryType
type Header ¶
type Header struct {
Version uint32
PrevBlockHash common.Uint256
TransactionsRoot common.Uint256
BlockRoot common.Uint256
Timestamp uint32
Height uint32
ConsensusData uint64
ConsensusPayload []byte
NextBookkeeper common.Address
//Program *program.Program
Bookkeepers []keypair.PublicKey
SigData [][]byte
// contains filtered or unexported fields
}
func (*Header) GetMessage ¶
func (*Header) SerializeUnsigned ¶
Serialize the blockheader data without program
type Payload ¶
type Payload interface {
//Serialize payload data
Serialize(w io.Writer) error
Deserialize(r io.Reader) error
}
Payload define the func for loading the payload data base on payload type which have different struture
type SmartCodeEvent ¶
type Transaction ¶
type Transaction struct {
Version byte
TxType TransactionType
Nonce uint32
GasPrice uint64
GasLimit uint64
Payer common.Address
Payload Payload
Sigs []*Sig
// contains filtered or unexported fields
}
func (*Transaction) Deserialize ¶
func (tx *Transaction) Deserialize(r io.Reader) error
deserialize the Transaction
func (*Transaction) DeserializeUnsigned ¶
func (tx *Transaction) DeserializeUnsigned(r io.Reader) error
func (*Transaction) GetMessage ¶
func (tx *Transaction) GetMessage() []byte
func (*Transaction) GetSignatureAddresses ¶
func (self *Transaction) GetSignatureAddresses() []common.Address
func (*Transaction) Hash ¶
func (tx *Transaction) Hash() common.Uint256
func (*Transaction) Serialize ¶
func (tx *Transaction) Serialize(w io.Writer) error
Serialize the Transaction
func (*Transaction) SerializeUnsigned ¶
func (tx *Transaction) SerializeUnsigned(w io.Writer) error
Serialize the Transaction data without contracts
func (*Transaction) SetHash ¶
func (tx *Transaction) SetHash(hash common.Uint256)
func (*Transaction) ToArray ¶
func (tx *Transaction) ToArray() []byte
func (*Transaction) Type ¶
func (tx *Transaction) Type() common.InventoryType
func (*Transaction) Verify ¶
func (tx *Transaction) Verify() error
type TransactionAttributeUsage ¶
type TransactionAttributeUsage byte
const ( Nonce TransactionAttributeUsage = 0x00 Script TransactionAttributeUsage = 0x20 DescriptionUrl TransactionAttributeUsage = 0x81 Description TransactionAttributeUsage = 0x90 )
type TransactionType ¶
type TransactionType byte
const ( Bookkeeper TransactionType = 0x02 Deploy TransactionType = 0xd0 Invoke TransactionType = 0xd1 )
type TxAttribute ¶
type TxAttribute struct {
Usage TransactionAttributeUsage
Data []byte
Size uint32
}
func NewTxAttribute ¶
func NewTxAttribute(u TransactionAttributeUsage, d []byte) TxAttribute
func (*TxAttribute) Deserialize ¶
func (tx *TxAttribute) Deserialize(r io.Reader) error
func (*TxAttribute) GetSize ¶
func (u *TxAttribute) GetSize() uint32
func (*TxAttribute) ToArray ¶
func (tx *TxAttribute) ToArray() []byte
Click to show internal directories.
Click to hide internal directories.